@@ -39,3 +39,27 @@ def test_scandate():
     s = e2.scans().first()
     r = s.resource('DICOM')
     assert(r.scandate() == '2008-05-06')
+
+
+def test_ftm_quantification():
+    r = e1.resource('FTM_QUANTIFICATION')
+    c1 = r.centiloids()
+    c2 = r.centiloids(False)
+    assert(c1 == -6.731959667125082)
+    assert(c2 == -7.958670071142706)
+
+
+def test_fdg_quantification():
+    r = e1.resource('FDG_QUANTIFICATION')
+    c1 = r.landau_signature()
+    v1 = float(c1.query('region == "landau_Composite"')['value'])
+    c2 = r.landau_signature(optimized=False)
+    v2 = float(c2.query('region == "landau_Composite"')['value'])
+    assert(v1 == 1.2596989870071411)
+    assert(v2 == 1.2491936683654783)
+
+
+def test_bamos_volume():
+    r = e1.resource('BAMOS')
+    v = r.volume()
+    assert(v == 4874.005882622703)
